
From: "Randy.Dunlap" <rddunlap@osdl.org>

io_remap_pfn_range() remaining callers:
  convert all remaining callers of io_remap_page_range()
  to io_remap_pfn_range();
  add io_remap_page_range() to feature-removal-schedule.txt;

Signed-off-by: Randy Dunlap <rddunlap@osdl.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/Documentation/feature-removal-schedule.txt |    9 +++++++++
 25-akpm/arch/sh/kernel/cpu/sh4/sq.c                |    2 +-
 25-akpm/drivers/video/acornfb.c                    |    2 +-
 25-akpm/drivers/video/au1100fb.c                   |    2 +-
 25-akpm/drivers/video/controlfb.c                  |    2 +-
 25-akpm/drivers/video/sa1100fb.c                   |    2 +-
 25-akpm/sound/core/pcm_native.c                    |    4 ++--
 7 files changed, 16 insertions(+), 7 deletions(-)

diff -puN arch/sh/kernel/cpu/sh4/sq.c~io_remap_pfn_range-convert-last-callers arch/sh/kernel/cpu/sh4/sq.c
--- 25/arch/sh/kernel/cpu/sh4/sq.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/arch/sh/kernel/cpu/sh4/sq.c	2005-03-18 13:50:56.000000000 -0800
@@ -379,7 +379,7 @@ static int sq_mmap(struct file *file, st
 
 	map = __sq_alloc_mapping(vma->vm_start, offset, size, "Userspace");
 
-	if (io_remap_page_range(vma, map->sq_addr, map->addr,
+	if (io_remap_pfn_range(vma, map->sq_addr, map->addr >> PAGE_SHIFT,
 				size, vma->vm_page_prot))
 		return -EAGAIN;
 
diff -puN Documentation/feature-removal-schedule.txt~io_remap_pfn_range-convert-last-callers Documentation/feature-removal-schedule.txt
--- 25/Documentation/feature-removal-schedule.txt~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/Documentation/feature-removal-schedule.txt	2005-03-18 13:50:56.000000000 -0800
@@ -31,3 +31,12 @@ Why:	It bloats the kernel unnecessarily,
 	(pciutils supports it.)  Will eliminate the need to try to keep the
 	pci.ids file in sync with the sf.net database all of the time.
 Who:	Greg Kroah-Hartman <gregkh@suse.de>
+
+---------------------------
+
+What:	io_remap_page_range() (macro or function)
+When:	September 2005
+Why:	Replaced by io_remap_pfn_range() which allows more memory space
+	addressabilty (by using a pfn) and supports sparc & sparc64
+	iospace as part of the pfn.
+Who:	Randy Dunlap <rddunlap@osdl.org>
diff -puN drivers/video/acornfb.c~io_remap_pfn_range-convert-last-callers drivers/video/acornfb.c
--- 25/drivers/video/acornfb.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/drivers/video/acornfb.c	2005-03-18 13:50:56.000000000 -0800
@@ -909,7 +909,7 @@ acornfb_mmap(struct fb_info *info, struc
 	 * some updates to the screen occasionally, but process switches
 	 * should cause the caches and buffers to be flushed often enough.
 	 */
-	if (io_remap_page_range(vma, vma->vm_start, off,
+	if (io_remap_pfn_range(vma, vma->vm_start, off >> PAGE_SHIFT,
 				vma->vm_end - vma->vm_start,
 				vma->vm_page_prot))
 		return -EAGAIN;
diff -puN drivers/video/au1100fb.c~io_remap_pfn_range-convert-last-callers drivers/video/au1100fb.c
--- 25/drivers/video/au1100fb.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/drivers/video/au1100fb.c	2005-03-18 13:50:56.000000000 -0800
@@ -408,7 +408,7 @@ au1100fb_mmap(struct fb_info *_fb,
 	/* This is an IO map - tell maydump to skip this VMA */
 	vma->vm_flags |= VM_IO;
 
-	if (io_remap_page_range(vma, vma->vm_start, off,
+	if (io_remap_pfn_range(vma, vma->vm_start, off >> PAGE_SHIFT,
 				vma->vm_end - vma->vm_start,
 				vma->vm_page_prot)) {
 		return -EAGAIN;
diff -puN drivers/video/controlfb.c~io_remap_pfn_range-convert-last-callers drivers/video/controlfb.c
--- 25/drivers/video/controlfb.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/drivers/video/controlfb.c	2005-03-18 13:50:56.000000000 -0800
@@ -315,7 +315,7 @@ static int controlfb_mmap(struct fb_info
        		return -EINVAL;
        off += start;
        vma->vm_pgoff = off >> PAGE_SHIFT;
-       if (io_remap_page_range(vma, vma->vm_start, off,
+       if (io_remap_pfn_range(vma, vma->vm_start, off >> PAGE_SHIFT,
            vma->vm_end - vma->vm_start, vma->vm_page_prot))
                return -EAGAIN;
 
diff -puN drivers/video/sa1100fb.c~io_remap_pfn_range-convert-last-callers drivers/video/sa1100fb.c
--- 25/drivers/video/sa1100fb.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/drivers/video/sa1100fb.c	2005-03-18 13:50:56.000000000 -0800
@@ -836,7 +836,7 @@ static int sa1100fb_mmap(struct fb_info 
 	vma->vm_pgoff = off >> PAGE_SHIFT;
 	vma->vm_flags |= VM_IO;
 	vma->vm_page_prot = pgprot_noncached(vma->vm_page_prot);
-	return io_remap_page_range(vma, vma->vm_start, off,
+	return io_remap_pfn_range(vma, vma->vm_start, off >> PAGE_SHIFT,
 				   vma->vm_end - vma->vm_start,
 				   vma->vm_page_prot);
 }
diff -puN sound/core/pcm_native.c~io_remap_pfn_range-convert-last-callers sound/core/pcm_native.c
--- 25/sound/core/pcm_native.c~io_remap_pfn_range-convert-last-callers	2005-03-18 13:50:56.000000000 -0800
+++ 25-akpm/sound/core/pcm_native.c	2005-03-18 13:50:56.000000000 -0800
@@ -3097,8 +3097,8 @@ int snd_pcm_lib_mmap_iomem(snd_pcm_subst
 	area->vm_flags |= VM_IO;
 	size = area->vm_end - area->vm_start;
 	offset = area->vm_pgoff << PAGE_SHIFT;
-	if (io_remap_page_range(area, area->vm_start,
-				substream->runtime->dma_addr + offset,
+	if (io_remap_pfn_range(area, area->vm_start,
+				(substream->runtime->dma_addr + offset) >> PAGE_SHIFT,
 				size, area->vm_page_prot))
 		return -EAGAIN;
 	atomic_inc(&substream->runtime->mmap_count);
_
